==> kdebindings-3.0.1.tar.bz2: kdebindings-3.0.1/kdejava/koala/org/kde/koala/StatJobSignals.java <==
package org.kde.koala;
import org.kde.qt.*;


/** {@link StatJob} emits these signals */
public interface StatJobSignals {

/** 
 Emitted when the slave successfully connected to the host.
 There is no guarantee the slave will send this, and this is
 currently unused (in the applications).
         
*/
	void connected( Job arg1 );
	void destroyed( QObject obj );

/** 
 Emitted to display information about this job, as sent by the slave.
 Examples of message are "Resolving host", "Connecting to host...", etc.
         
*/
	void infoMessage( Job arg1, String msg );

/** 
 Regularly emitted to show the progress of this job
 (current data size for transfers, entries listed).
         
*/
	void processedSize( Job arg1, int size );

/** 
 Emitted when the job is finished, in any case (completed, canceled,
 failed...). Use {@link error} to know the result.
         
*/
	void result( Job job );

/** 
 Emitted when the job is canceled.

 Signal <code>result</code> is emitted as well, and error() is,
 in this case, ERR_USER_CANCELED.
         
*/
	void canceled( Job job );

/** 
 Signals a redirection.
 Use to update the URL shown to the user.
 The redirection itself is handled internally.
         
*/
	void redirection( Job arg1, KURL url );

/** 
 Emitted when we know the size of this job (data size for transfers,
 number of entries for listings).
         
*/
	void totalSize( Job arg1, int size );

/** 
 Progress signal showing the overall progress of the job
 This is valid for any kind of job, and allows using a
 a progress bar very easily. (see {@link KProgress})
         
*/
	void percent( Job job, long percent );

/** 
 Emitted to display information about the speed of this job.
         
*/
	void speed( Job arg1, long bytes_per_second );
}

==> kdebindings-3.1.3.tar.bz2: kdebindings-3.1.3/kdejava/koala/org/kde/koala/StatJobSignals.java <==
package org.kde.koala;
import org.kde.qt.*;


/** {@link StatJob} emits these signals */
public interface StatJobSignals {

/** 
 Emitted when the slave successfully connected to the host.
 There is no guarantee the slave will send this, and this is
 currently unused (in the applications).
         
*/
	void connected( Job arg1 );

/** 
 Emitted to display information about the speed of this job.
         
*/
	void speed( Job arg1, long bytes_per_second );

/** 
 Emitted when the job is finished, in any case (completed, canceled,
 failed...). Use {@link StatJob#error} to know the result.
         
*/
	void result( Job job );

/** 
 Regularly emitted to show the progress of this job
 (current data size for transfers, entries listed).
         
*/
	void processedSize( Job arg1, int size );

/** 
 Signals a redirection.
 Use to update the URL shown to the user.
 The redirection itself is handled internally.
         
*/
	void redirection( Job arg1, KURL url );

/** 
 Emitted to display information about this job, as sent by the slave.
 Examples of message are "Resolving host", "Connecting to host...", etc.
         
*/
	void infoMessage( Job arg1, String msg );
	void destroyed( QObject obj );

/** 
 Signals a permanent redirection.
 The redirection itself is handled internally.

*/
	void permanentRedirection( Job arg1, KURL fromUrl, KURL toUrl );

/** 
 Emitted when the job is canceled.

 Signal <code>result</code> is emitted as well, and error() is,
 in this case, ERR_USER_CANCELED.
         
*/
	void canceled( Job job );

/** 
 Progress signal showing the overall progress of the job
 This is valid for any kind of job, and allows using a
 a progress bar very easily. (see {@link KProgress}).
 Note that this signal is not emitted for finished jobs
 (i.e. percent is never 100).
         
*/
	void percent( Job job, long percent );

/** 
 Emitted when we know the size of this job (data size for transfers,
 number of entries for listings).
         
*/
	void totalSize( Job arg1, int size );
}
